@@ -1,3 +1,4 @@
+import logging
 import json
 
 from requests import get, post
@@ -15,6 +16,8 @@ retention = None
 subdomain = None
 volume_limit = None
 
+log = logging.getLogger(__name__)
+
 # Exception related stuff
 class LogglyError(Exception):
     pass
@@ -29,6 +32,10 @@ class RequestError(LogglyError):
         self.status_code = response.status_code
         self.reason = response.reason
 
+    def __repr__(self):
+        return '<RequestError status_code={} reason={} message={}>'.format(
+            self.status_code, self.reason, self.message )
+
 class InvalidStatError(LogglyError):
     def __init__(self, stat):
         self.stat = stat
@@ -63,11 +70,14 @@ class SearchIterator(object):
     def __next__(self):
         if self.url is None: raise StopIteration
 
-        response = SearchIterator.get_page(self.url, self.auth, self.params)
-        self.url = response['next'] if 'next' in response else None
-        if 'events' in response:
-            return response['events']
-        return list()
+        try:
+            response = SearchIterator.get_page(self.url, self.auth, self.params)
+            self.url = response['next'] if 'next' in response else None
+            if 'events' in response:
+                return response['events']
+                return list()
+        except RequestError as e:
+            log.error('Received a bad response from Loggly: {}'.format(e.__str__()))
 
     def get_page(url, auth, params):
         response = None
@@ -247,4 +257,3 @@ def stats(stat='all', field=None, query='*', frm=None, til=None):
             raise RequestError(response)
     else:
         raise AuthenticationError()
-
